==> gaphor-2.6.0.tar.gz: gaphor-2.6.0/gaphor/RAAML/fta/notgate.py <==
"""NOT gate item definition."""

from gaphas.geometry import Rectangle

from gaphor.core.modeling import DrawContext
from gaphor.diagram.presentation import (
    Classified,
    ElementPresentation,
    from_package_str,
)
from gaphor.diagram.shapes import Box, IconBox, Text, stroke
from gaphor.diagram.support import represents
from gaphor.diagram.text import FontStyle, FontWeight
from gaphor.RAAML import raaml
from gaphor.RAAML.fta.constants import DEFAULT_FTA_MAJOR, DEFAULT_FTA_MINOR
from gaphor.UML.modelfactory import stereotypes_str


@represents(raaml.NOT)
class NOTItem(ElementPresentation, Classified):
    def __init__(self, diagram, id=None):
        super().__init__(diagram, id, width=DEFAULT_FTA_MINOR, height=DEFAULT_FTA_MAJOR)

        self.watch("subject[NamedElement].name").watch(
            "subject[NamedElement].namespace.name"
        )

    def update_shapes(self, event=None):
        self.shape = IconBox(
            Box(
                draw=draw_not_gate,
            ),
            Text(
                text=lambda: stereotypes_str(self.subject, ["NOT"]),
            ),
            Text(
                text=lambda: self.subject.name or "",
                width=lambda: self.width - 4,
                style={
                    "font-weight": FontWeight.BOLD,
                    "font-style": FontStyle.NORMAL,
                },
            ),
            Text(
                text=lambda: from_package_str(self),
                style={"font-size": "x-small"},
            ),
        )


def draw_not_gate(box, context: DrawContext, bounding_box: Rectangle):
    cr = context.cairo
    x1 = 0
    x2 = bounding_box.width
    height = bounding_box.height
    cr.move_to(x1, height)
    cr.line_to(x2, 0)
    cr.line_to(x1, 0)
    cr.line_to(x2, height)
    cr.line_to(x1, height)
    stroke(context)

==> gaphor-2.7.0.tar.gz: gaphor-2.7.0/gaphor/RAAML/fta/notgate.py <==
"""NOT gate item definition."""

from gaphas.geometry import Rectangle

from gaphor.core import gettext
from gaphor.core.modeling import DrawContext
from gaphor.diagram.presentation import (
    Classified,
    ElementPresentation,
    from_package_str,
)
from gaphor.diagram.shapes import Box, IconBox, Text, stroke
from gaphor.diagram.support import represents
from gaphor.diagram.text import FontStyle, FontWeight
from gaphor.RAAML import raaml
from gaphor.RAAML.fta.constants import DEFAULT_FTA_MAJOR, DEFAULT_FTA_MINOR
from gaphor.UML.modelfactory import stereotypes_str


@represents(raaml.NOT)
class NOTItem(ElementPresentation, Classified):
    def __init__(self, diagram, id=None):
        super().__init__(diagram, id, width=DEFAULT_FTA_MINOR, height=DEFAULT_FTA_MAJOR)

        self.watch("subject[NamedElement].name").watch(
            "subject[NamedElement].namespace.name"
        )

    def update_shapes(self, event=None):
        self.shape = IconBox(
            Box(
                draw=draw_not_gate,
            ),
            Text(
                text=lambda: stereotypes_str(self.subject, [gettext("NOT Gate")]),
            ),
            Text(
                text=lambda: self.subject.name or "",
                width=lambda: self.width - 4,
                style={
                    "font-weight": FontWeight.BOLD,
                    "font-style": FontStyle.NORMAL,
                },
            ),
            Text(
                text=lambda: from_package_str(self),
                style={"font-size": "x-small"},
            ),
        )


def draw_not_gate(box, context: DrawContext, bounding_box: Rectangle):
    cr = context.cairo
    x1 = 0
    x2 = bounding_box.width
    height = bounding_box.height
    cr.move_to(x1, height)
    cr.line_to(x2, 0)
    cr.line_to(x1, 0)
    cr.line_to(x2, height)
    cr.line_to(x1, height)
    stroke(context)
